EventError

Enum EventError 

pub enum EventError {
Show 24 variants UnsupportedFormat(u32), UnknownRequired(String), Sequence { expected: u64, actual: u64, }, SessionMismatch, DuplicateSession, ConcurrentRun, SessionClosed, RunMismatch, InteractionMismatch, OpenLifecycle, DuplicateInput(InputId), UnqueuedInput(InputId), UnclaimedInput(InputId), ConcurrentTurn, ConcurrentStep, LifecycleMismatch, DuplicateToolCall(ToolCallId), OrphanToolResult(ToolCallId), ToolResultMismatch(ToolCallId), UsageConflict(String), ConcurrentCompaction, CompactionMismatch, Conflict(String), Unavailable(String),
}
Invariant violated while applying an event.

Variants



UnsupportedFormat(u32)

Unsupported session event format version.



UnknownRequired(String)

Unknown required session event type.



Sequence

Event sequence mismatch: expected expected, got actual.

Fields

expected: u64

Sequence the projection expected next.

actual: u64

Sequence the event carried.



SessionMismatch

Event belongs to another session.



DuplicateSession

Session creation must be the first and only creation event.



ConcurrentRun

Session already has an active run.



SessionClosed

Session is closed.



RunMismatch

Event does not match the active run.



InteractionMismatch

Interaction does not match the waiting run.



OpenLifecycle

Run cannot finish with an open turn, step or tool call.



DuplicateInput(InputId)

Input was queued twice.



UnqueuedInput(InputId)

Input was claimed before it was queued.



UnclaimedInput(InputId)

Run started from an unclaimed input.



ConcurrentTurn

Session already has an active turn.



ConcurrentStep

Turn already has this active step.



LifecycleMismatch

Turn or step lifecycle does not pair.



DuplicateToolCall(ToolCallId)

Duplicate tool call.



OrphanToolResult(ToolCallId)

Tool result has no matching call.



ToolResultMismatch(ToolCallId)

Tool result does not match the call run and step.



UsageConflict(String)

Usage operation was recorded with different totals.



ConcurrentCompaction

Session already has an active compaction.



CompactionMismatch

Compaction lifecycle does not pair.



Conflict(String)

Event store conflict.



Unavailable(String)

Event store unavailable.